BagEndsConfig = {}

local BagEndsFrame = CreateFrame( "Frame", "BagEndsConfigFrame", InterfaceOptionsFramePanelContainer)
local Title = BagEndsConfigFrame:CreateFontString( "BagEndsTitle", nil, "GameFontNormalLarge")
local OutlineToggle = CreateFrame( "CheckButton", "OutlineBagsToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local TextToggle = CreateFrame( "CheckButton", "ShowTextToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local ColorToggle = CreateFrame( "CheckButton", "ColorTextToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local OccupiedToggle = CreateFrame( "CheckButton", "OccupiedTextToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )
local ShowTotalToggle = CreateFrame( "CheckButton", "ShowTotalTextToggle", BagEndsFrame, "InterfaceOptionsCheckButtonTemplate" )

local function SetDefaults()
	BagEndsConfig.outline = true
	BagEndsConfig.showText = true
	BagEndsConfig.colorText = false
	BagEndsConfig.occupied = false
	BagEndsConfig.showTotal = true
	BagEndsConfig.savedVariables = true
end

local function UpdateConfig()
	
	if (OutlineBagsToggle:GetChecked()) then
		BagEndsConfig.outline = true
	else
		BagEndsConfig.outline = false
	end
	
	if (ShowTextToggle:GetChecked()) then
		BagEndsConfig.showText = true
		
		ColorTextToggle:Enable()
		OccupiedTextToggle:Enable()
		ShowTotalTextToggle:Enable()
		
		if (ColorTextToggle:GetChecked()) then
			BagEndsConfig.colorText = true
		else
			BagEndsConfig.colorText = false
		end
		
		if (OccupiedTextToggle:GetChecked()) then
			BagEndsConfig.occupied = true
		else
			BagEndsConfig.occupied = false
		end
		
		if (ShowTotalTextToggle:GetChecked()) then
			BagEndsConfig.showTotal = true
		else
			BagEndsConfig.showTotal = false
		end
		
	else
		BagEndsConfig.showText = false
		ColorTextToggle:Disable()
		OccupiedTextToggle:Disable()
		ShowTotalTextToggle:Disable()
	end
	


	BagEndsUpdate()
end

local function BagEndsConfigInit()
	BagEndsFrame.name = "Bag Ends"
 
	BagEndsTitle:SetPoint("TOPLEFT", 16,-16)
	BagEndsTitle:SetText("Bag Ends")
 
	ShowTextToggle:SetPoint( "TOPLEFT", 16, -48 )
	ShowTextToggle:SetScript("OnClick", UpdateConfig)
	ShowTextToggle:SetChecked(BagEndsConfig.showText)
	ShowTextToggleText:SetText("Show Bag Status Text")
		
	ColorTextToggle:SetPoint( "TOPLEFT", 32, -80 )
	ColorTextToggle:SetScript("OnClick", UpdateConfig)
	ColorTextToggle:SetChecked(BagEndsConfig.colorText)
	ColorTextToggleText:SetText("Color Status Text")
	
	OccupiedTextToggle:SetPoint( "TOPLEFT", 32, -112 )
	OccupiedTextToggle:SetScript("OnClick", UpdateConfig)
	OccupiedTextToggle:SetChecked(BagEndsConfig.occupied)
	OccupiedTextToggleText:SetText("Count Full Bag Slots")
	
	ShowTotalTextToggle:SetPoint( "TOPLEFT", 32, -144 )
	ShowTotalTextToggle:SetScript("OnClick", UpdateConfig)
	ShowTotalTextToggle:SetChecked(BagEndsConfig.showTotal)
	ShowTotalTextToggleText:SetText("Show Total Bag Size")

	OutlineBagsToggle:SetPoint( "TOPLEFT", 16, -176 )
	OutlineBagsToggle:SetScript("OnClick", UpdateConfig)
	OutlineBagsToggle:SetChecked(BagEndsConfig.outline)
	OutlineBagsToggleText:SetText("Show Bag Status Outline")
	
	if (BagEndsConfig.showText == false) then
		ColorTextToggle:Disable()
		OccupiedTextToggle:Disable()
		ShowTotalTextToggle:Disable()
	end
	
	InterfaceOptions_AddCategory(BagEndsFrame)
end

function BagEndsEventHandler(event, arg1)
	if (BagEndsConfig.savedVariables) then
		BagEndsConfigInit()
	else
		SetDefaults()
		BagEndsConfigInit()
	end
	print(GetAddOnMetadata("BagEnds", "Title") .. " v" .. GetAddOnMetadata("BagEnds", "Version") .. " Loaded")
end

BagEndsFrame:RegisterEvent("VARIABLES_LOADED")
BagEndsFrame:SetScript("OnEvent", BagEndsEventHandler)